# ResponseGT
ResponseGT is a software that computes electrical/mechanical flow within a graph network.

## 1. Prerequisites
This software requires Python version 3.12. Install it from [here](https://www.python.org/downloads/).

## 2 Installation

The software can be installed via ```pip``` or ```Conda```.

### 2a. Install via pip

To install the software via ```pip```:

```bash
pip install rgtlib
```

### 2b. Install via Conda

To install the software via ```Conda```:

```bash
conda install -c conda-forge rgtlib
```

## 3. Usage

To run the GUI application, please follow these steps:

* Open a terminal application such as ```CMD``` and execute the following command:

```bash
ResponseGT
```
